@@ -1,6 +1,7 @@
 #define BSD386
 #include "bsd.h"
 
+
 #ifdef __ELF__
 /* #if ! defined(IN_UNIXFASL) */
 #undef HAVE_AOUT
@@ -42,21 +43,40 @@ do {static struct sigaction action; \
       sigaction(SIGSEGV,&action,0); \
       sigaction(SIGBUS,&action,0);} while (0)
 
-#include <asm/sigcontext.h>
-/* #include <asm/signal.h> */
+/* the following two files have changed back
+   and forth in recent versions of linux...
+   Include both if they both exist, otherwise
+   include whatever one exists...
+   basically one wants the
+   struct sigcontext_struct { ... } ;
+   so as to get the fault address.
+   */
+     
+#include <asm/sigcontext.h> 
+#include <asm/signal.h>
 
-#define GET_FAULT_ADDR(sig,code,sv,a) \
+
+  /*  This was
     ((void *)(((struct sigcontext_struct *)(&code))->cr2))
+    but surely that must be wrong... ie why would the address
+    of the argument be relevant..
+   */
+#define GET_FAULT_ADDR(sig,code,sv,a) \
+    ((void *)(((struct sigcontext_struct *)(code))->cr2))     
 #endif
 
+
 #define ELF_TEXT_BASE 0x8000000  /* Later Linux ELF releases may change this */
 #define DBEGIN ELF_TEXT_BASE
 
+
+
 #undef SET_REAL_MAXPAGE
 #define SET_REAL_MAXPAGE do { struct rlimit data_rlimit; \
+                               extern char etext; \
 			       real_maxpage = MAXPAGE ;\
      	getrlimit(RLIMIT_DATA, &data_rlimit); \
-	real_maxpage = ((unsigned int)&etext \
+			real_maxpage = ((unsigned int)&etext \
 			+ data_rlimit.rlim_cur - ELF_TEXT_BASE)/PAGESIZE; \
 	if (real_maxpage > MAXPAGE) \
 		real_maxpage = MAXPAGE ; } while(0)
