@@ -903,12 +903,15 @@ EXTER object MVloc[10];
 
 /* Set new to be an (object *) whose [i]'th elmt is the
    ith elmnt in a va_list
-   MUST_COPY_VA_LIST should be true, if
-   ((vl[0] != va_arg(ap,object)) ||
-    (vl[1] != va_arg(ap,object)) || .. vl[n-1] != va_arg(ap,object))
-   Normal machines have va_list an ordinary array and a copy is unnecessary.
+   if 
+   ((vl[0] == va_arg(ap,object)) ||
+    (vl[1] == va_arg(ap,object)) || .. vl[n-1] == va_arg(ap,object))
+   you may set
+   #define DONT_COPY_VA_LIST
+   In recent versions of gcc, i think the builtin_alist stuff does not
+   allow setting this.
  */
-#ifndef MUST_COPY_VA_LIST
+#ifdef DONT_COPY_VA_LIST
 #define COERCE_VA_LIST(new,vl,n) new = (object *) (vl)
 #else
 #define COERCE_VA_LIST(new,vl,n) \
@@ -1870,7 +1873,6 @@ object one_minus();
 
 /*  num_co.c  */
 object double_to_integer();
-object remainder();
 
 /*  num_log.c  */
 object shift_integer();
