@@ -43,13 +43,13 @@ main(argc,argv)
 
 static Elf32_Ehdr *file_h;
 static Elf32_Shdr *section_h;
-static caddr_t base;
+
+static struct sect *section;
 static char *string_table;
 static char *section_names;
 static int text_index;
 struct sect {int start;
       };
-static struct sect *section;
 
 static int symsize;
 
@@ -69,6 +69,8 @@ round_up(address,n)
 }
 #define ROUND_UP(a,b) round_up(a,b) 
 
+int use_mmap;
+
 fasload(faslfile)
      object faslfile;
 {  FILE *fp;
@@ -84,6 +86,8 @@ fasload(faslfile)
    int init_address=0;
    int extra_bss=0;
    object memory;
+   caddr_t base;
+
    int current = 0,max_align = 0;
    struct sect section_org[40];
    Elf32_Sym *symbol_table;
@@ -105,7 +109,16 @@ fasload(faslfile)
    if (fstat (file, &stat_buf) == -1)
      FEerror ("Can't fstat(~a): errno %d\n", 1,faslfile);
 
-   base = mmap (0, stat_buf.st_size,PROT_READ|PROT_WRITE, MAP_PRIVATE, file, 0);
+
+   if (use_mmap) {
+     base = mmap (0, stat_buf.st_size,PROT_READ|PROT_WRITE, MAP_PRIVATE, file, 0); } else {
+
+   base = malloc(stat_buf.st_size);
+   fread(base,1,stat_buf.st_size,fp);
+   fseek(fp,0,SEEK_CUR);
+     }
+
+   
 
    if (base == (caddr_t) -1)
      FEerror ("Can't mmap(~a):",1,faslfile);
@@ -194,7 +207,7 @@ fasload(faslfile)
    
    relocate_symbols(symbol_table,nsyms);
 
-   {
+   { int rel_stab_index = -1;
      int j=0;
      for (j=1 ; j <  file_h->e_shnum ; j++)
        {
@@ -215,8 +228,10 @@ fasload(faslfile)
 	       FEerror("unexpected symbol table used");
 	     the_start = start_address + section[index_to_relocate].start;
 	   }
+	 
 	 else if ( (shp->sh_type == SHT_REL) || (shp->sh_type == SHT_RELA) )
-	   {
+	   {  if (get_section_number(".rel.stab") == j)
+	         continue;
 	     FEerror("unknown rel type");
 	   }
 	 else
@@ -231,13 +246,21 @@ fasload(faslfile)
    }
 
    SEEK_TO_END_OFILE(fp);
+
+   init_address = section[text_index].start;
    
    if (feof(fp))
      data=0;
    else
+   /* after hear any of the 'static' variables must not be
+      referred to any more */
      data = read_fasl_vector(faslfile);
 
+  if (use_mmap) 
    munmap(base, stat_buf.st_size);
+   else
+   free(base);
+  
 
    close_stream(faslfile);
 
@@ -245,7 +268,6 @@ fasload(faslfile)
    CLEAR_CACHE;
 #endif
 
-   init_address = section[text_index].start;
    call_init(init_address,memory,data,0);
 	
    vs_base = old_vs_base;
