@@ -556,7 +556,7 @@ int *bottom,*top;
     than 4 we need to mark twice
    */
 
- if (offset) {sgc_mark_stack_carefully(bottom,(((char *) top) +offset),0);}
+ if (offset) {sgc_mark_stack_carefully((((char *) top) +offset),bottom,0);}
  for (j=top ; j >= bottom ; j--)
    {if (VALID_DATA_ADDRESS_P(*j)
 	&& type_map[(p=page(*j))]< (char)t_end)
@@ -624,7 +624,7 @@ sgc_mark_phase()
 
 	sgc_mark_stack_carefully(vs_top-1,vs_org,0);
 	clear_stack(vs_top,vs_limit);
-	sgc_mark_stack_carefully(MVloc,MVloc+(sizeof(MVloc)/sizeof(object)),0);
+	sgc_mark_stack_carefully(MVloc+(sizeof(MVloc)/sizeof(object)),MVloc,0);
 	/* 
 	for (p = vs_org;  p < vs_top;  p++) {
 	  if (p && (inheap(*p)))
@@ -1110,7 +1110,7 @@ make_writable(beg,i)
 
 int debug_fault =0;
 int fault_count =0;
-extern char *etext;
+extern char etext;
 void
 memprotect_handler(sig, code, scp, addr)
           int sig, code;
@@ -1121,7 +1121,7 @@ memprotect_handler(sig, code, scp, addr)
  char *faddr;  /* Needed because we must not modify signal handler
 		  arguments on the stack! */
 #ifdef GET_FAULT_ADDR
- faddr=GET_FAULT_ADDR(sig,code,scp,addr);
+  faddr=GET_FAULT_ADDR(sig,code,scp,addr); 
  debug_fault = (int) faddr;
 #ifdef DEBUG_MPROTECT
  printf("fault:0x%x [%d] (%d)  ",faddr,page(faddr),faddr >= core_end);
